@@ -68,7 +68,7 @@ def archive(path: Path, tar_path: Path) -> Path:
     logger.debug("Archive will be created at: %s", tar_path)
 
     file_count = 0
-    with fastar.open(tar_path, "w") as tar:
+    with fastar.open(tar_path, "w:zst") as tar:
         for filename in files:
             if filename.is_dir():
                 continue
@@ -193,13 +193,13 @@ def _upload_deployment(deployment_id: str, archive_path: Path) -> None:
         upload_data = model_validate(RequestUploadResponse, response.json())
         logger.debug("Received upload URL: %s", upload_data.url)
 
-        # Upload the archive
         logger.debug("Starting file upload to S3")
-        upload_response = client.post(
-            upload_data.url,
-            data=upload_data.fields,
-            files={"file": archive_path.open("rb")},
-        )
+        with open(archive_path, "rb") as archive_file:
+            upload_response = client.post(
+                upload_data.url,
+                data=upload_data.fields,
+                files={"file": archive_file},
+            )
 
         upload_response.raise_for_status()
         logger.debug("File upload completed successfully")
@@ -260,8 +260,7 @@ LONG_WAIT_MESSAGES = [
 
 
 def _configure_app(toolkit: RichToolkit, path_to_deploy: Path) -> AppConfig:
-    if not toolkit.confirm(f"Setup and deploy [blue]{path_to_deploy}[/]?", tag="dir"):
-        raise typer.Exit(0)
+    toolkit.print(f"Setting up and deploying [blue]{path_to_deploy}[/blue]", tag="path")
 
     toolkit.print_line()
 
